#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
.. moduleauthor:: Peter M. Landwehr <plandweh@cs.cmu.edu>
"""
__author__ = 'Peter M. Landwehr <plandweh@cs.cmu.edu>'
__version__ = '0.11'

#from DynamicMetaNetwork import DynamicMetaNetwork

#import dynetml2other
from dynetml2other import main as dynetml2other
from MetaNetwork import MetaNetwork
from DynamicMetaNetwork import DynamicMetaNetwork


#from MetaNetworkDict import MetaNetworkDict
#from MetaNetworkIGraph import MetaNetworkIG
#from MetaNetworkNetworkX import MetaNetworkNX

